export declare enum Workflow {
    Generic = "generic",
    Managed = "managed"
}
export declare enum CredentialsSource {
    LOCAL = "local",
    REMOTE = "remote",
    AUTO = "auto"
}
export interface AndroidManagedBuildProfile {
    workflow: Workflow.Managed;
    credentialsSource: CredentialsSource;
    buildType?: 'app-bundle' | 'apk';
}
export interface AndroidGenericBuildProfile {
    workflow: Workflow.Generic;
    credentialsSource: CredentialsSource;
    buildCommand?: string;
    artifactPath?: string;
    withoutCredentials?: boolean;
}
export interface iOSManagedBuildProfile {
    workflow: Workflow.Managed;
    credentialsSource: CredentialsSource;
    buildType?: 'archive' | 'simulator';
}
export interface iOSGenericBuildProfile {
    workflow: Workflow.Generic;
    credentialsSource: CredentialsSource;
}
export declare type AndroidBuildProfile = AndroidManagedBuildProfile | AndroidGenericBuildProfile;
export declare type iOSBuildProfile = iOSManagedBuildProfile | iOSGenericBuildProfile;
export interface EasConfig {
    builds: {
        android?: AndroidManagedBuildProfile | AndroidGenericBuildProfile;
        ios?: iOSManagedBuildProfile | iOSGenericBuildProfile;
    };
}
export declare class EasJsonReader {
    private projectDir;
    private platform;
    constructor(projectDir: string, platform: 'android' | 'ios' | 'all');
    readAsync(buildProfileName: string): Promise<EasConfig>;
    private validateBuildProfile;
    private readFile;
}
